import { Injectable, NgModule, Component, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReplaySubject } from 'rxjs/ReplaySubject';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LoaderService {
    constructor() {
        this.loader = ['<div class="km-overlay">',
            '<div class="km-modal km-vertical" id="modal">',
            '<div class="km-modal-content">',
            '<div class="km-loader km-vertical"></div>',
            '</div>',
            '</div>',
            '</div>'];
    }
    /**
     * @return {?}
     */
    showDialog() {
        const /** @type {?} */ div = document.createElement('div');
        div.className = 'km-dialog-loader';
        div.innerHTML = this.loader.join(' ');
        document.body.appendChild(div);
    }
    /**
     * @return {?}
     */
    closeDialog() {
        document.querySelector('.km-dialog-loader').remove();
    }
}
LoaderService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
LoaderService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LoaderModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: LoaderModule,
            providers: [
                LoaderService
            ]
        };
    }
}
LoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [],
                exports: []
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ProcessflowService {
    constructor() {
        this.updateSteps = new ReplaySubject();
    }
}
ProcessflowService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ProcessflowService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ProcessflowComponent {
    /**
     * @param {?} processFlowService
     */
    constructor(processFlowService) {
        this.processFlowService = processFlowService;
        this.stages = [];
        this.error = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.stages instanceof Array && this.stages.length > 0) {
            this.noOfStages = this.stages.length;
        }
        else {
            this.error = true;
        }
        this.initStepWatcher();
    }
    /**
     * @return {?}
     */
    initStepWatcher() {
        this.processFlowService.updateSteps.subscribe(newStages => {
            this.stages = newStages;
        });
    }
}
ProcessflowComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-processflow',
                template: `<div *ngIf="!error; else  showMessage">
    <ul class="stepper">
      <li *ngFor="let step of stages" [ngClass]="step.status" [style.width]="(100/stages.length)+'%'">{{step.label}}</li>
    </ul>
</div>
<ng-template #showMessage> Please validate your input. It should be array of objects </ng-template>

`,
                styles: [`@import url(https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css);@import url(https://fonts.googleapis.com/css?family=Open+Sans|Source+Sans+Pro);*{font-family:SourceSansPro,Helvetica,Arial,sans-serif}.stepper{counter-reset:step;padding:0;margin:0;font-family:SourceSansPro,Helvetica,Arial,sans-serif}.stepper li{list-style-type:none;display:inline-block;position:relative;cursor:pointer;font-size:12px;text-align:center;color:#445864;font-family:SourceSansPro,Helvetica,Arial,sans-serif}.stepper li.complete::before{background:#56bc62;border:1px solid #4cae50;content:"\\f00c";font-family:FontAwesome}.stepper li::before{content:counter(step);counter-increment:step;width:20px;height:20px;line-height:20px;border-radius:100%;display:block;text-align:center;margin:0 auto 10px;background-color:#cfd1d4;border:1px solid #c0c3c9;-webkit-box-shadow:0 0 0 5px #ebebeb;box-shadow:0 0 0 5px #ebebeb;color:#fff;z-index:200;position:relative}.stepper li::after{content:"";position:absolute;width:100%;height:2px;top:10px;left:-50%;z-index:100;background-color:#e5e5e5;border:1px solid #c6c6c6}.stepper li:first-child::after{content:none}.stepper li.active::before{background-color:#278dfe;border:1px solid #2c86ae}`]
            },] },
];
/** @nocollapse */
ProcessflowComponent.ctorParameters = () => [
    { type: ProcessflowService, },
];
ProcessflowComponent.propDecorators = {
    "stages": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ProcessflowModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: ProcessflowModule,
            providers: [
                ProcessflowService
            ]
        };
    }
}
ProcessflowModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [ProcessflowComponent],
                exports: [ProcessflowComponent],
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const types = {
    'AVAL': 'aval',
    'SEL': 'sel',
    'RIGHT': 'right',
    'LEFT': 'left'
};
class TransferBoxComponent {
    constructor() {
        this.updateList = new EventEmitter();
        this.selectAlls = false;
        this.selectAlla = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} type
     * @param {?} value
     * @return {?}
     */
    selectAll(type, value) {
        if (type === types.AVAL) {
            this.selectAlla = !this.selectAlla;
            value = this.selectAlla;
        }
        else {
            this.selectAlls = !this.selectAlls;
            value = this.selectAlls;
        }
        this.changeSelected(type === types.AVAL ? this.available : this.selected, value);
    }
    ;
    /**
     * @param {?} list
     * @param {?} value
     * @return {?}
     */
    changeSelected(list, value) {
        list.forEach(obj => {
            obj.selected = value;
        });
    }
    /**
     * @param {?} item
     * @return {?}
     */
    selectItem(item) {
        item.selected = item.selected ? false : true;
    }
    /**
     * @param {?} item
     * @param {?} side
     * @return {?}
     */
    moveItem(item, side) {
        item.selected = false;
        let /** @type {?} */ copy = Object.assign({}, item);
        if (side === types.RIGHT) {
            this.selected.push(copy);
            item.delete = true;
            this.available = this.removeItems(this.available);
        }
        else {
            this.available.push(copy);
            item.delete = true;
            this.selected = this.removeItems(this.selected);
        }
        this.updateData();
    }
    /**
     * @return {?}
     */
    updateData() {
        this.selectAlla = false;
        this.selectAlls = false;
        let /** @type {?} */ data = { "selected": this.selected, "available": this.available };
        this.updateList.emit(data);
    }
    /**
     * @param {?} list
     * @return {?}
     */
    removeItems(list) {
        list = list.filter(obj => {
            return obj.delete != true;
        });
        return list;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    moveAll(value) {
        if (types.RIGHT === value) {
            this.moveObjects(this.available, this.selected);
            this.available = this.removeItems(this.available);
        }
        else if (types.LEFT === value) {
            this.moveObjects(this.selected, this.available);
            this.selected = this.removeItems(this.selected);
        }
        this.updateData();
    }
    /**
     * @param {?} source
     * @param {?} dest
     * @return {?}
     */
    moveObjects(source, dest) {
        source.forEach(obj => {
            if (obj.selected || obj.selected == "true") {
                obj.selected = false;
                dest.push(Object.assign({}, obj));
                obj.delete = true;
            }
        });
    }
}
TransferBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-transfer-box',
                template: `<div class="flex-container">
  <div class="flex-item-6 transferbox shadow">
    <div class="flex-item-12 header">
      Available 
      <span class="badge">{{available.length}}</span>
      <span> <button (click)="selectAll('aval',!selectAlls)" [disabled]="available.length == 0"> Select All </button></span>
      <span> <button [disabled]="available.length == 0" (click)="moveAll('right')"> > </button></span>
    </div>
    <div class="flex-item-12 body">
      <div class="transferbox-item" *ngFor="let item of available;" [ngClass]="item.selected ? 'selected' : 'none'" 
        (click)="selectItem(item)" (dblclick)="moveItem(item,'right')"> {{item.label }} </div>
    </div>
  </div>
  <div class="flex-item-6 transferbox shadow">
      <div class="flex-item-12 header">
          <span> <button [disabled]="selected.length == 0" (click)="moveAll('left')"> < </button></span>
         <span> <button (click)="selectAll('sel',!selectAlla)" [disabled]="selected.length == 0" > DeSelect All </button></span>
         Selected 
         <span class="badge">{{selected.length}}</span>
        </div>
        <div class="flex-item-12 body">
            <div class="transferbox-item" *ngFor="let item of selected;" [ngClass]="item.selected ? 'selected' : 'none'" 
            (click)="selectItem(item)" (dblclick)="moveItem(item,'left')"> {{item.label }} </div>
        </div>
  </div>
</div>`,
                styles: [`.flex-container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row wrap;flex-flow:row wrap;-ms-flex-pack:distribute;justify-content:space-around;padding:2px}.flex-container-start{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row wrap;flex-flow:row wrap;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.flex-container .flex-item-12{clear:both;width:100%}@media screen and (min-width:480px){.flex-container .flex-item-6{width:49%;float:left}}@media screen and (max-width:480px){.flex-container .flex-item-6{width:100%}}.text-left{text-align:left}.text-right{text-align:right}.text-center{text-align:center}.badge{display:inline-block;padding-left:8px;padding-right:8px;text-align:center;background-color:#333;color:#fff;border-radius:50%;line-height:1.5em}.shadow{-webkit-box-shadow:0 3px 11px 0 rgba(0,0,0,.11);box-shadow:0 3px 11px 0 rgba(0,0,0,.11);background:#fff}.header{border-bottom:1px solid #ddd;height:50px}.transferbox{border:1px solid #ddd;padding:2px}.selected,.transferbox-item:hover{background-color:#489cdf;color:#fff}.transferbox-item{border-bottom:1px solid #e0dcdc;padding:6px}.transferbox-item:last-child{border-bottom:none}`]
            },] },
];
/** @nocollapse */
TransferBoxComponent.ctorParameters = () => [];
TransferBoxComponent.propDecorators = {
    "available": [{ type: Input, args: ['available',] },],
    "selected": [{ type: Input, args: ['selected',] },],
    "updateList": [{ type: Output, args: ['update',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TransferboxModule {
}
TransferboxModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                exports: [TransferBoxComponent],
                declarations: [TransferBoxComponent]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { LoaderService, LoaderModule, ProcessflowService, ProcessflowModule, TransferboxModule, ProcessflowComponent as ɵa, TransferBoxComponent as ɵb };
//# sourceMappingURL=angular-dev-lib.js.map
