import { Injectable, NgModule, Component, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ReplaySubject } from 'rxjs/ReplaySubject';

var LoaderService = (function () {
    function LoaderService() {
        this.loader = ['<div class="km-overlay">',
            '<div class="km-modal km-vertical" id="modal">',
            '<div class="km-modal-content">',
            '<div class="km-loader km-vertical"></div>',
            '</div>',
            '</div>',
            '</div>'];
    }
    LoaderService.prototype.showDialog = function () {
        var div = document.createElement('div');
        div.className = 'km-dialog-loader';
        div.innerHTML = this.loader.join(' ');
        document.body.appendChild(div);
    };
    LoaderService.prototype.closeDialog = function () {
        document.querySelector('.km-dialog-loader').remove();
    };
    return LoaderService;
}());
LoaderService.decorators = [
    { type: Injectable },
];
LoaderService.ctorParameters = function () { return []; };
var LoaderModule = (function () {
    function LoaderModule() {
    }
    LoaderModule.forRoot = function () {
        return {
            ngModule: LoaderModule,
            providers: [
                LoaderService
            ]
        };
    };
    return LoaderModule;
}());
LoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [],
                exports: []
            },] },
];
var ProcessflowService = (function () {
    function ProcessflowService() {
        this.updateSteps = new ReplaySubject();
    }
    return ProcessflowService;
}());
ProcessflowService.decorators = [
    { type: Injectable },
];
ProcessflowService.ctorParameters = function () { return []; };
var ProcessflowComponent = (function () {
    function ProcessflowComponent(processFlowService) {
        this.processFlowService = processFlowService;
        this.stages = [];
        this.error = false;
    }
    ProcessflowComponent.prototype.ngOnInit = function () {
        if (this.stages instanceof Array && this.stages.length > 0) {
            this.noOfStages = this.stages.length;
        }
        else {
            this.error = true;
        }
        this.initStepWatcher();
    };
    ProcessflowComponent.prototype.initStepWatcher = function () {
        var _this = this;
        this.processFlowService.updateSteps.subscribe(function (newStages) {
            _this.stages = newStages;
        });
    };
    return ProcessflowComponent;
}());
ProcessflowComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-processflow',
                template: "<div *ngIf=\"!error; else  showMessage\">\n    <ul class=\"stepper\">\n      <li *ngFor=\"let step of stages\" [ngClass]=\"step.status\" [style.width]=\"(100/stages.length)+'%'\">{{step.label}}</li>\n    </ul>\n</div>\n<ng-template #showMessage> Please validate your input. It should be array of objects </ng-template>\n\n",
                styles: ["@import url(https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css);@import url(https://fonts.googleapis.com/css?family=Open+Sans|Source+Sans+Pro);*{font-family:SourceSansPro,Helvetica,Arial,sans-serif}.stepper{counter-reset:step;padding:0;margin:0;font-family:SourceSansPro,Helvetica,Arial,sans-serif}.stepper li{list-style-type:none;display:inline-block;position:relative;cursor:pointer;font-size:12px;text-align:center;color:#445864;font-family:SourceSansPro,Helvetica,Arial,sans-serif}.stepper li.complete::before{background:#56bc62;border:1px solid #4cae50;content:\"\\f00c\";font-family:FontAwesome}.stepper li::before{content:counter(step);counter-increment:step;width:20px;height:20px;line-height:20px;border-radius:100%;display:block;text-align:center;margin:0 auto 10px;background-color:#cfd1d4;border:1px solid #c0c3c9;-webkit-box-shadow:0 0 0 5px #ebebeb;box-shadow:0 0 0 5px #ebebeb;color:#fff;z-index:200;position:relative}.stepper li::after{content:\"\";position:absolute;width:100%;height:2px;top:10px;left:-50%;z-index:100;background-color:#e5e5e5;border:1px solid #c6c6c6}.stepper li:first-child::after{content:none}.stepper li.active::before{background-color:#278dfe;border:1px solid #2c86ae}"]
            },] },
];
ProcessflowComponent.ctorParameters = function () { return [
    { type: ProcessflowService, },
]; };
ProcessflowComponent.propDecorators = {
    "stages": [{ type: Input },],
};
var ProcessflowModule = (function () {
    function ProcessflowModule() {
    }
    ProcessflowModule.forRoot = function () {
        return {
            ngModule: ProcessflowModule,
            providers: [
                ProcessflowService
            ]
        };
    };
    return ProcessflowModule;
}());
ProcessflowModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [ProcessflowComponent],
                exports: [ProcessflowComponent],
            },] },
];
var types = {
    'AVAL': 'aval',
    'SEL': 'sel',
    'RIGHT': 'right',
    'LEFT': 'left'
};
var TransferBoxComponent = (function () {
    function TransferBoxComponent() {
        this.updateList = new EventEmitter();
        this.selectAlls = false;
        this.selectAlla = false;
    }
    TransferBoxComponent.prototype.ngOnInit = function () {
    };
    TransferBoxComponent.prototype.selectAll = function (type, value) {
        if (type === types.AVAL) {
            this.selectAlla = !this.selectAlla;
            value = this.selectAlla;
        }
        else {
            this.selectAlls = !this.selectAlls;
            value = this.selectAlls;
        }
        this.changeSelected(type === types.AVAL ? this.available : this.selected, value);
    };
    
    TransferBoxComponent.prototype.changeSelected = function (list, value) {
        list.forEach(function (obj) {
            obj.selected = value;
        });
    };
    TransferBoxComponent.prototype.selectItem = function (item) {
        item.selected = item.selected ? false : true;
    };
    TransferBoxComponent.prototype.moveItem = function (item, side) {
        item.selected = false;
        var copy = Object.assign({}, item);
        if (side === types.RIGHT) {
            this.selected.push(copy);
            item.delete = true;
            this.available = this.removeItems(this.available);
        }
        else {
            this.available.push(copy);
            item.delete = true;
            this.selected = this.removeItems(this.selected);
        }
        this.updateData();
    };
    TransferBoxComponent.prototype.updateData = function () {
        this.selectAlla = false;
        this.selectAlls = false;
        var data = { "selected": this.selected, "available": this.available };
        this.updateList.emit(data);
    };
    TransferBoxComponent.prototype.removeItems = function (list) {
        list = list.filter(function (obj) {
            return obj.delete != true;
        });
        return list;
    };
    TransferBoxComponent.prototype.moveAll = function (value) {
        if (types.RIGHT === value) {
            this.moveObjects(this.available, this.selected);
            this.available = this.removeItems(this.available);
        }
        else if (types.LEFT === value) {
            this.moveObjects(this.selected, this.available);
            this.selected = this.removeItems(this.selected);
        }
        this.updateData();
    };
    TransferBoxComponent.prototype.moveObjects = function (source, dest) {
        source.forEach(function (obj) {
            if (obj.selected || obj.selected == "true") {
                obj.selected = false;
                dest.push(Object.assign({}, obj));
                obj.delete = true;
            }
        });
    };
    return TransferBoxComponent;
}());
TransferBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-transfer-box',
                template: "<div class=\"flex-container\">\n  <div class=\"flex-item-6 transferbox shadow\">\n    <div class=\"flex-item-12 header\">\n      Available \n      <span class=\"badge\">{{available.length}}</span>\n      <span> <button (click)=\"selectAll('aval',!selectAlls)\" [disabled]=\"available.length == 0\"> Select All </button></span>\n      <span> <button [disabled]=\"available.length == 0\" (click)=\"moveAll('right')\"> > </button></span>\n    </div>\n    <div class=\"flex-item-12 body\">\n      <div class=\"transferbox-item\" *ngFor=\"let item of available;\" [ngClass]=\"item.selected ? 'selected' : 'none'\" \n        (click)=\"selectItem(item)\" (dblclick)=\"moveItem(item,'right')\"> {{item.label }} </div>\n    </div>\n  </div>\n  <div class=\"flex-item-6 transferbox shadow\">\n      <div class=\"flex-item-12 header\">\n          <span> <button [disabled]=\"selected.length == 0\" (click)=\"moveAll('left')\"> < </button></span>\n         <span> <button (click)=\"selectAll('sel',!selectAlla)\" [disabled]=\"selected.length == 0\" > DeSelect All </button></span>\n         Selected \n         <span class=\"badge\">{{selected.length}}</span>\n        </div>\n        <div class=\"flex-item-12 body\">\n            <div class=\"transferbox-item\" *ngFor=\"let item of selected;\" [ngClass]=\"item.selected ? 'selected' : 'none'\" \n            (click)=\"selectItem(item)\" (dblclick)=\"moveItem(item,'left')\"> {{item.label }} </div>\n        </div>\n  </div>\n</div>",
                styles: [".flex-container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row wrap;flex-flow:row wrap;-ms-flex-pack:distribute;justify-content:space-around;padding:2px}.flex-container-start{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row wrap;flex-flow:row wrap;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.flex-container .flex-item-12{clear:both;width:100%}@media screen and (min-width:480px){.flex-container .flex-item-6{width:49%;float:left}}@media screen and (max-width:480px){.flex-container .flex-item-6{width:100%}}.text-left{text-align:left}.text-right{text-align:right}.text-center{text-align:center}.badge{display:inline-block;padding-left:8px;padding-right:8px;text-align:center;background-color:#333;color:#fff;border-radius:50%;line-height:1.5em}.shadow{-webkit-box-shadow:0 3px 11px 0 rgba(0,0,0,.11);box-shadow:0 3px 11px 0 rgba(0,0,0,.11);background:#fff}.header{border-bottom:1px solid #ddd;height:50px}.transferbox{border:1px solid #ddd;padding:2px}.selected,.transferbox-item:hover{background-color:#489cdf;color:#fff}.transferbox-item{border-bottom:1px solid #e0dcdc;padding:6px}.transferbox-item:last-child{border-bottom:none}"]
            },] },
];
TransferBoxComponent.ctorParameters = function () { return []; };
TransferBoxComponent.propDecorators = {
    "available": [{ type: Input, args: ['available',] },],
    "selected": [{ type: Input, args: ['selected',] },],
    "updateList": [{ type: Output, args: ['update',] },],
};
var TransferboxModule = (function () {
    function TransferboxModule() {
    }
    return TransferboxModule;
}());
TransferboxModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                exports: [TransferBoxComponent],
                declarations: [TransferBoxComponent]
            },] },
];

export { LoaderService, LoaderModule, ProcessflowService, ProcessflowModule, TransferboxModule, ProcessflowComponent as ɵa, TransferBoxComponent as ɵb };
//# sourceMappingURL=angular-dev-lib.js.map
